@@ -1026,8 +1026,8 @@ class Decorator(Base):
                 surf_rect.x += pos[0]
                 surf_rect.y += pos[1]
                 if centered:
-                    surf_rect.x -= surf_rect.width / 2
-                    surf_rect.y -= surf_rect.height / 2
+                    surf_rect.x -= int(surf_rect.width / 2)
+                    surf_rect.y -= int(surf_rect.height / 2)
                 surface.blit(surf, surf_rect)
 
             elif dtype == DECORATION_ELLIPSE:
@@ -1116,6 +1116,7 @@ class Decorator(Base):
         """
         if not use_center_positioning:
             return tuple(pos)
+
         cx, cy = rect.centerx, rect.centery  # Center position
 
         # Position of the rect has not changed and exists
@@ -1133,6 +1134,7 @@ class Decorator(Base):
             new_pos.append((int(p[0] + cx), int(p[1] + cy)))
         new_pos = tuple(new_pos)
         self._coord_cache[decoid] = (cx, cy, new_pos)
+
         return new_pos
 
 
