@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
@@ -6,9 +5,6 @@ https://github.com/ppizarror/pygame-menu
 EXAMPLE - DYNAMIC WIDGET UPDATE
 Dynamically updates the widgets based on user events.
 
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
-
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -33,41 +29,46 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
-import sys
-import os
-import math
-
-sys.path.insert(0, '../../')
+__all__ = ['main']
 
 import pygame
 import pygame_menu
+from pygame_menu.examples import create_example_window
+
+import math
+from typing import Dict, Any
 
 
 class App(object):
     """
     The following object creates the whole app.
     """
+    image_widget: 'pygame_menu.widgets.Image'
+    item_description_widget: 'pygame_menu.widgets.Label'
+    menu: 'pygame_menu.Menu'
+    modes: Dict[int, Dict[str, Any]]
+    quit_button: 'pygame_menu.widgets.Button'
+    quit_button_fake: 'pygame_menu.widgets.Button'
+    selector_widget: 'pygame_menu.widgets.Selector'
+    surface: 'pygame.Surface'
 
-    def __init__(self):
+    def __init__(self) -> None:
         """
         Constructor.
         """
-
-        # Start pygame
-        pygame.init()
-        os.environ['SDL_VIDEO_CENTERED'] = '1'
-        try:
-            self.surface = pygame.display.set_mode((640, 480), flags=pygame.NOFRAME)
-        except TypeError:
-            self.surface = pygame.display.set_mode((640, 480))
+        self.surface = create_example_window('Example - Dynamic Widget Update',
+                                             (640, 480), flags=pygame.NOFRAME)
 
         # Load image
-        default_image = pygame_menu.baseimage.BaseImage(
+        default_image = pygame_menu.BaseImage(
             image_path=pygame_menu.baseimage.IMAGE_EXAMPLE_PYGAME_MENU
         ).scale(0.2, 0.2)
 
         # Set theme
-        theme = pygame_menu.themes.THEME_DEFAULT
+        theme = pygame_menu.themes.THEME_DEFAULT.copy()
+        theme.title_bar_style = pygame_menu.widgets.MENUBAR_STYLE_UNDERLINE_TITLE
+        theme.title_close_button_cursor = pygame_menu.locals.CURSOR_HAND
+        theme.title_font_color = (35, 35, 35)
 
         # This dict stores the values of the widgets to be changed dynamically
         self.modes = {
@@ -106,53 +107,55 @@ class App(object):
             width=640
         )
 
-        self.selector_widget = self.menu.add_selector(
+        self.selector_widget = self.menu.add.selector(
             title='Pick one option: ',
             items=[('The first', 1),
                    ('The second', 2),
                    ('The final mode', 3)],
             onchange=self._on_selector_change
-        )  # type: pygame_menu.widgets.Selector
+        )
 
-        self.image_widget = self.menu.add_image(
+        self.image_widget = self.menu.add.image(
             image_path=self.modes[1]['image'],
             padding=(25, 0, 0, 0)  # top, right, bottom, left
-        )  # type: pygame_menu.widgets.Image
+        )
 
-        self.item_description_widget = self.menu.add_label(title='')  # type: pygame_menu.widgets.Label
+        self.item_description_widget = self.menu.add.label(title='')
 
-        self.quit_button = self.menu.add_button('Quit', pygame_menu.events.EXIT)
+        self.quit_button = self.menu.add.button('Quit', pygame_menu.events.EXIT)
 
-        self.quit_button_fake = self.menu.add_button('You cannot quit', self.fake_quit, font_color=(255, 255, 255))
+        self.quit_button_fake = self.menu.add.button('You cannot quit', self.fake_quit,
+                                                     font_color=(255, 255, 255))
         self.quit_button_fake.add_draw_callback(self.animate_quit_button)
 
-        # Update the widgets based on selected value from selector
-        # get_value returns selected item tuple and index, so [0][1] means the second object from ('The first', 1) tuple
-        self._update_from_selection(self.selector_widget.get_value()[0][1])
+        # Update the widgets based on selected value from selector get_value
+        # returns selected item tuple and index, so [0][1] means the second object
+        # from ('The first', 1) tuple
+        self._update_from_selection(int(self.selector_widget.get_value()[0][1]))
 
-    def animate_quit_button(self, widget, menu):
+    def animate_quit_button(
+            self,
+            widget: 'pygame_menu.widgets.Widget',
+            menu: 'pygame_menu.Menu'
+    ) -> None:
         """
         Animate widgets if the last option is selected.
 
         :param widget: Widget to be updated
-        :type widget: :py:class:`pygame_menu.widgets.core.widget.Widget`
         :param menu: Menu
-        :type menu: :py:class:`pygame_menu.Menu`
         :return: None
         """
         if self.current == 3:
-            t = widget.get_attribute('t', default=math.pi)
-            t += menu.get_clock().get_time() * 0.001
-            widget.set_attribute('t', t)
+            t = widget.get_counter_attribute('t', menu.get_clock().get_time() * 0.0075, math.pi)
             widget.set_padding(10 * (1 + math.sin(t)))  # Oscillating padding
-            new_color = (int(125 * (1 + math.sin(t))), 0, 0)
-            widget.set_background_color(new_color, None)
-            widget.update_font({'background_color': new_color})
-            widget.translate(10 * math.cos(t), 10 * math.sin(t))
+            widget.set_background_color((int(125 * (1 + math.sin(t))), 0, 0), None)
+            c = int(127 * (1 + math.cos(t)))
+            widget.update_font({'color': (c, c, c)})  # Widget font now is in grayscale
+            # widget.translate(10 * math.cos(t), 10 * math.sin(t))
             widget.rotate(5 * t)
 
     @staticmethod
-    def fake_quit():
+    def fake_quit() -> None:
         """
         Function executed by fake quit button.
 
@@ -160,12 +163,11 @@ class App(object):
         """
         print('I said that you cannot quit')
 
-    def _update_from_selection(self, index):
+    def _update_from_selection(self, index: int) -> None:
         """
         Change widgets depending on index.
 
         :param index: Index
-        :type index: int
         :return: None
         """
         self.current = index
@@ -183,39 +185,36 @@ class App(object):
             self.quit_button.show()
             self.quit_button_fake.hide()
 
-    def _on_selector_change(self, selected, value):
+    def _on_selector_change(self, selected: Any, value: int) -> None:
         """
         Function executed if selector changes.
 
-        :param selected: Selector data (tuple) containing text and index
-        :type selected: tuple
+        :param selected: Selector data containing text and index
         :param value: Value from the selected option
-        :type value: int
         :return: None
         """
         print('Selected data:', selected)
         self._update_from_selection(value)
 
-    def mainloop(self, test):
+    def mainloop(self, test: bool) -> None:
         """
         App mainloop.
 
         :param test: Test status
-        :type test: bool
         """
         self.menu.mainloop(self.surface, disable_loop=test)
 
 
-def main(test=False):
+def main(test: bool = False) -> 'App':
     """
     Main function.
 
     :param test: Indicate function is being tested
-    :type test: bool
-    :return: None
+    :return: App object
     """
     app = App()
     app.mainloop(test)
+    return app
 
 
 if __name__ == '__main__':
