@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
@@ -6,9 +5,6 @@ https://github.com/ppizarror/pygame-menu
 FONTS
 Menu fonts.
 
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
-
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -33,8 +29,39 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
+__all__ = [
+
+    # Fonts path included in resources
+    'FONT_8BIT',
+    'FONT_BEBAS',
+    'FONT_COMIC_NEUE',
+    'FONT_DIGITAL',
+    'FONT_FRANCHISE',
+    'FONT_HELVETICA',
+    'FONT_MUNRO',
+    'FONT_NEVIS',
+    'FONT_OPEN_SANS',
+    'FONT_OPEN_SANS_BOLD',
+    'FONT_OPEN_SANS_ITALIC',
+    'FONT_OPEN_SANS_LIGHT',
+    'FONT_PT_SERIF',
+    'FONT_EXAMPLES',
+
+    # Typing
+    'FontType',
+    'FontInstance',
+
+    # Utils
+    'assert_font',
+    'get_font'
+
+]
+
+from pathlib import Path
+from typing import Union, Optional, Any
 import os.path as path
-import pygame.font as _font
+
+import pygame.font as __font
 
 # Available fonts path
 __fonts_path__ = path.join(path.dirname(path.abspath(__file__)), 'resources', 'fonts', '{0}')
@@ -42,6 +69,7 @@ __fonts_path__ = path.join(path.dirname(path.abspath(__file__)), 'resources', 'f
 FONT_8BIT = __fonts_path__.format('8bit.ttf')
 FONT_BEBAS = __fonts_path__.format('bebas.ttf')
 FONT_COMIC_NEUE = __fonts_path__.format('comic_neue.ttf')
+FONT_DIGITAL = __fonts_path__.format('digital.ttf')
 FONT_FRANCHISE = __fonts_path__.format('franchise.ttf')
 FONT_HELVETICA = __fonts_path__.format('helvetica.ttf')
 FONT_MUNRO = __fonts_path__.format('munro.ttf')
@@ -50,32 +78,49 @@ FONT_OPEN_SANS = __fonts_path__.format('opensans_regular.ttf')
 FONT_OPEN_SANS_BOLD = __fonts_path__.format('opensans_bold.ttf')
 FONT_OPEN_SANS_ITALIC = __fonts_path__.format('opensans_italic.ttf')
 FONT_OPEN_SANS_LIGHT = __fonts_path__.format('opensans_light.ttf')
-FONT_PT_SERIF = __fonts_path__.format('pt_serif.ttf')
+FONT_PT_SERIF = __fonts_path__.format('ptserif_regular.ttf')
 
-FONT_EXAMPLES = (FONT_8BIT, FONT_BEBAS, FONT_COMIC_NEUE, FONT_FRANCHISE, FONT_HELVETICA,
-                 FONT_MUNRO, FONT_NEVIS, FONT_OPEN_SANS, FONT_OPEN_SANS_BOLD, FONT_OPEN_SANS_ITALIC,
-                 FONT_OPEN_SANS_LIGHT, FONT_PT_SERIF)
+FONT_EXAMPLES = (FONT_8BIT, FONT_BEBAS, FONT_COMIC_NEUE, FONT_DIGITAL, FONT_FRANCHISE,
+                 FONT_HELVETICA, FONT_MUNRO, FONT_NEVIS, FONT_OPEN_SANS,
+                 FONT_OPEN_SANS_BOLD, FONT_OPEN_SANS_ITALIC, FONT_OPEN_SANS_LIGHT,
+                 FONT_PT_SERIF)
 
 # Stores font cache
 _cache = {}
 
+FontType = Union[str, __font.Font, Path]
+FontInstance = (str, __font.Font, Path)
 
-def get_font(name, size):
+
+def assert_font(font: Any) -> None:
+    """
+    Asserts if the given object is a font type.
+
+    :param font: Font object
+    :return: None
+    """
+    assert isinstance(font, FontInstance), \
+        'value must be a font type (str, Path, pygame.Font)'
+
+
+def get_font(name: FontType, size: int) -> '__font.Font':
     """
     Return a :py:class:`pygame.font.Font` object from a name or file.
 
     :param name: Font name or path
-    :type name: str, :py:class:`pygame.font.Font`
-    :param size: Font size (px)
-    :type size: int
+    :param size: Font size in px
     :return: Font object
-    :rtype: :py:class:`pygame.font.Font`
     """
+    assert_font(name)
     assert isinstance(size, int)
-    if isinstance(name, _font.Font):
-        font = name  # type: (_font.Font,None)
+
+    font: Optional['__font.Font']
+    if isinstance(name, __font.Font):
+        font = name
         return font
+
     else:
+        name = str(name)
 
         if name == '':
             raise ValueError('font name cannot be empty')
@@ -86,25 +131,25 @@ def get_font(name, size):
         # Font is not a file, then use a system font
         if not path.isfile(name):
             font_name = name
-            name = _font.match_font(font_name)
+            name = __font.match_font(font_name)
 
             if name is None:  # Show system available fonts
                 from difflib import SequenceMatcher
                 from random import randrange
-                system_fonts = _font.get_fonts()
+                system_fonts = __font.get_fonts()
 
                 # Get the most similar example
                 most_similar = 0
                 most_similar_index = 0
                 for i in range(len(system_fonts)):
                     # noinspection PyArgumentEqualDefault
-                    sim = SequenceMatcher(None, system_fonts[i], font_name).ratio()  # Similarity
+                    sim = SequenceMatcher(None, system_fonts[i], font_name).ratio()
                     if sim > most_similar:
                         most_similar = sim
                         most_similar_index = i
                 sys_font_sim = system_fonts[most_similar_index]
-                sys_suggestion = 'system font "{0}" unknown, use "{1}" instead'.format(font_name,
-                                                                                       sys_font_sim)
+                sys_suggestion = 'system font "{0}" unknown, use "{1}" instead' \
+                                 ''.format(font_name, sys_font_sim)
                 sys_message = 'check system fonts with pygame.font.get_fonts() function'
 
                 # Get examples
@@ -123,16 +168,15 @@ def get_font(name, size):
                 sys_message_2 = 'some examples: {0}'.format(fonts_random)
 
                 # Raise the exception
-                raise ValueError('{0}\n{1}\n{2}'.format(sys_suggestion,
-                                                        sys_message,
-                                                        sys_message_2))
+                raise ValueError('{0}\n{1}\n{2}'
+                                 ''.format(sys_suggestion, sys_message, sys_message_2))
 
         # Try to load the font
-        font = None  # type: (_font.Font,None)
+        font = None
         if (name, size) in _cache:
             return _cache[(name, size)]
         try:
-            font = _font.Font(name, size)
+            font = __font.Font(name, size)
         except IOError:
             pass
 
