@@ -56,7 +56,7 @@ import pygame_menu.controls as ctrl
 from pygame_menu.locals import FINGERUP, POSITION_EAST, POSITION_WEST, POSITION_NORTH, \
     POSITION_SOUTH
 from pygame_menu.utils import assert_color, get_finger_pos, warn
-from pygame_menu.widgets.core import Widget
+from pygame_menu.widgets.core.widget import Widget, WidgetTransformationNotImplemented
 
 from pygame_menu._types import Tuple, CallbackType, Tuple2IntType, Literal, Any, \
     Optional, NumberInstance, ColorInputType, EventVectorType, VectorInstance, \
@@ -88,12 +88,12 @@ class MenuBar(Widget):
     """
     MenuBar widget.
 
-     .. note::
+    .. note::
 
         MenuBar only accepts translation transformation.
 
     :param title: Title of the menubar
-    :param width: Width of the widget, generally width of the Menu
+    :param width: Width of the widget, generally the same as the width of the menu
     :param background_color: Background color
     :param menubar_id: ID of the MenuBar
     :param back_box: Draw a back-box button on header
@@ -140,6 +140,8 @@ class MenuBar(Widget):
         assert isinstance(width, NumberInstance)
         assert isinstance(back_box, bool)
 
+        assert width > 0, 'width must be greater or equal than zero'
+
         background_color = assert_color(background_color)
         back_box_background_color = assert_color(back_box_background_color)
 
@@ -183,19 +185,22 @@ class MenuBar(Widget):
         return self
 
     def scale(self, *args, **kwargs) -> 'MenuBar':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def resize(self, *args, **kwargs) -> 'MenuBar':
-        return self
-
-    def rotate(self, *args, **kwargs) -> 'MenuBar':
-        return self
-
-    def set_max_height(self, *args, **kwargs) -> 'MenuBar':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def set_max_width(self, *args, **kwargs) -> 'MenuBar':
-        return self
+        raise WidgetTransformationNotImplemented()
+
+    def set_max_height(self, *args, **kwargs) -> 'MenuBar':
+        raise WidgetTransformationNotImplemented()
+
+    def rotate(self, *args, **kwargs) -> 'MenuBar':
+        raise WidgetTransformationNotImplemented()
+
+    def flip(self, *args, **kwargs) -> 'MenuBar':
+        raise WidgetTransformationNotImplemented()
 
     def set_selection_effect(self, *args, **kwargs) -> 'MenuBar':
         return self
@@ -203,9 +208,6 @@ class MenuBar(Widget):
     def set_border(self, *args, **kwargs) -> 'MenuBar':
         return self
 
-    def flip(self, *args, **kwargs) -> 'MenuBar':
-        return self
-
     def _check_title_color(self, background_menu: bool) -> None:
         """
         Performs title color and prints a warning if the color is similar to the
