@@ -34,16 +34,18 @@ __all__ = ['NoneWidget']
 import pygame
 
 from pygame_menu.utils import make_surface
-from pygame_menu.widgets.core import Widget
+from pygame_menu.widgets.core.widget import Widget, WidgetTransformationNotImplemented
 
-from pygame_menu._types import Optional, NumberType
+from pygame_menu._types import Optional, NumberType, EventVectorType
 
 
 # noinspection PyMissingOrEmptyDocstring
 class NoneWidget(Widget):
     """
     None widget. Useful if used for filling column/row layout. None widget don't
-    accept padding, margin, cannot be selected or updated.
+    accept values, padding, margin, cursors, position, sound, controls, and
+    cannot be selected. Also, none widget cannot accept callbacks, except draw
+    and update callbacks.
 
     .. note::
 
@@ -114,26 +116,26 @@ class NoneWidget(Widget):
     def set_position(self, *args, **kwargs) -> 'NoneWidget':
         return self
 
-    def flip(self, *args, **kwargs) -> 'NoneWidget':
-        return self
-
-    def set_max_width(self, *args, **kwargs) -> 'NoneWidget':
-        return self
-
-    def set_max_height(self, *args, **kwargs) -> 'NoneWidget':
-        return self
-
     def scale(self, *args, **kwargs) -> 'NoneWidget':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def resize(self, *args, **kwargs) -> 'NoneWidget':
-        return self
+        raise WidgetTransformationNotImplemented()
 
-    def translate(self, *args, **kwargs) -> 'NoneWidget':
-        return self
+    def set_max_width(self, *args, **kwargs) -> 'NoneWidget':
+        raise WidgetTransformationNotImplemented()
+
+    def set_max_height(self, *args, **kwargs) -> 'NoneWidget':
+        raise WidgetTransformationNotImplemented()
 
     def rotate(self, *args, **kwargs) -> 'NoneWidget':
-        return self
+        raise WidgetTransformationNotImplemented()
+
+    def flip(self, *args, **kwargs) -> 'NoneWidget':
+        raise WidgetTransformationNotImplemented()
+
+    def translate(self, *args, **kwargs) -> 'NoneWidget':
+        raise WidgetTransformationNotImplemented()
 
     def set_alignment(self, *args, **kwargs) -> 'NoneWidget':
         return self
@@ -153,18 +155,6 @@ class NoneWidget(Widget):
     def set_controls(self, *args, **kwargs) -> 'NoneWidget':
         return self
 
-    def set_value(self, *args, **kwargs) -> None:
-        pass
-
-    def add_update_callback(self, *args, **kwargs) -> None:
-        pass
-
-    def remove_update_callback(self, *args, **kwargs) -> 'NoneWidget':
-        return self
-
-    def apply_update_callbacks(self, *args, **kwargs) -> 'NoneWidget':
-        return self
-
     def set_border(self, *args, **kwargs) -> 'NoneWidget':
         return self
 
@@ -201,8 +191,6 @@ class NoneWidget(Widget):
     def set_tab_size(self, *args, **kwargs) -> 'NoneWidget':
         return self
 
-    def set_default_value(self, *args, **kwargs) -> 'NoneWidget':
-        return self
-
-    def update(self, *args, **kwargs) -> bool:
+    def update(self, events: EventVectorType) -> bool:
+        self.apply_update_callbacks(events)
         return False
