@@ -37,7 +37,7 @@ from pygame_menu.locals import ORIENTATION_VERTICAL, ORIENTATION_HORIZONTAL, \
     POSITION_NORTHWEST, FINGERMOTION, FINGERUP, FINGERDOWN
 from pygame_menu.utils import make_surface, assert_orientation, \
     mouse_motion_current_mouse_position, assert_color, get_finger_pos
-from pygame_menu.widgets.core import Widget
+from pygame_menu.widgets.core.widget import Widget, WidgetTransformationNotImplemented
 
 from pygame_menu._types import Optional, List, VectorIntType, ColorType, Literal, \
     Tuple2IntType, CallbackType, NumberInstance, ColorInputType, NumberType, \
@@ -138,6 +138,7 @@ class ScrollBar(Widget):
         self._page_ctrl_thick = page_ctrl_thick
 
         # Slider
+        self._default_value = 0
         self._slider_color = slider_color
         self._slider_hover_color = slider_hover_color
         self._slider_pad = slider_pad
@@ -177,22 +178,22 @@ class ScrollBar(Widget):
         return self
 
     def scale(self, *args, **kwargs) -> 'ScrollBar':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def resize(self, *args, **kwargs) -> 'ScrollBar':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def set_max_width(self, *args, **kwargs) -> 'ScrollBar':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def set_max_height(self, *args, **kwargs) -> 'ScrollBar':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def rotate(self, *args, **kwargs) -> 'ScrollBar':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def flip(self, *args, **kwargs) -> 'ScrollBar':
-        return self
+        raise WidgetTransformationNotImplemented()
 
     def _apply_size_changes(self) -> None:
         """
@@ -553,7 +554,7 @@ class ScrollBar(Widget):
                 )
 
                 # If mouse outside region and scroll is on limits, ignore
-                mx, my = pygame.mouse.get_pos() if event.type == pygame.MOUSEMOTION else \
+                mx, my = event.pos if event.type == pygame.MOUSEMOTION else \
                     get_finger_pos(self._menu, event)
                 if self.get_value_percentage() in (0, 1) and \
                         self.get_scrollarea() is not None and \
